#!/bin/bash

# Terminate configure if no PgPool-II installed in system
array=($(rpmquery -a | grep pgpool))
if [[ ${#array[@]} == 0 ]]; then
    echo "PgPool-II not installed!"
    exit 0
fi

. ../contrib/functions.sh
. ../contrib/config

read -r -p "Configure PgPool-II. Continue ? [y/N]" choice
if ! [[ $choice =~ ^([yY][eE][sS]]|[yY])$ ]]; then
    exit 0
fi

TYPE=primary
VERBOSE=false
CATEGORY=a

usage="$(basename "$0") [-h] [-p] [-s] [-a|b|c]-- Script configure pgpool-II
 where:
     -h  show this help text and exit
     -p  configure pgpool as primary
     -s  configure pgpool as standby
     -a  configure pgpool for category A
     -b  configure pgpool for category B
     -c  configure pgpool for category C"

while getopts ':psvh' option; do
    case "$option" in
        p) TYPE=primary
            ;;
        s) TYPE=standby
            ;;
        v) VERBOSE=true
            ;;
        a) CATEGORY=a
            ;;
        b) CATEGORY=b
            ;;
        c) CATEGORY=c
            ;;
        h) echo "$usage"
            exit
            ;;
        \?) printf "illegal option: -%s\n" "$OPTARG" >&2
            echo "$usage" >&2
            exit 1
           ;;
   esac
done

read -r -p "For which server will be configured PgPool-II(primary | standby) (Default: $TYPE):" _TYPE
if [[ ! -z $_TYPE ]]; then
    TYPE=$_TYPE
fi
read -r -p "PgPool primary host (Default: $PGPOOL_PRIMARY_HOST):" _PGPOOL_PRIMARY_HOST
if [[ ! -z $_PGPOOL_PRIMARY_HOST ]]; then
    PGPOOL_PRIMARY_HOST=$_PGPOOL_PRIMARY_HOST
fi
read -r -p "PgPool standby host (Default: $PGPOOL_STANDBY_HOST):" _PGPOOL_STANDBY_HOST
if [[ ! -z $_PGPOOL_STANDBY_HOST ]]; then
    PGPOOL_STANDBY_HOST=$_PGPOOL_STANDBY_HOST
fi
read -r -p "PgPool trusted servers (Default: $PGPOOL_TRUSTED_SERVERS):" _PGPOOL_TRUSTED_SERVERS
if [[ ! -z $_PGPOOL_TRUSTED_SERVERS ]]; then
    PGPOOL_TRUSTED_SERVERS=$_PGPOOL_TRUSTED_SERVERS
fi
read -r -p "PgPool delegate ip (Default: $PGPOOL_DELEGATE_IP):" _PGPOOL_DELEGATE_IP
if [[ ! -z $_PGPOOL_DELEGATE_IP ]]; then
    PGPOOL_DELEGATE_IP=$_PGPOOL_DELEGATE_IP
fi
read -r -p "PgPool virtual ip interface (Default: $PGPOOL_INTERFACE):" _PGPOOL_INTERFACE
if [[ ! -z $_PGPOOL_INTERFACE ]]; then
    PGPOOL_INTERFACE=$_PGPOOL_INTERFACE
fi

# pgpool dir
PGPOOL_DIR=/etc/pgpool-II
PGPOOL_CONFIG=$PGPOOL_DIR/pgpool.conf

cp -rf pgpool-II/pgpool-$TYPE.conf $PGPOOL_CONFIG
cp -rf init.d/pgpool /etc/init.d/pgpool
cp -rf sysconfig/pgpool /etc/sysconfig/pgpool

sed -i 's/__PGPOOL_PRIMARY_HOST__/'$PGPOOL_PRIMARY_HOST'/g' $PGPOOL_CONFIG
sed -i 's/__PGPOOL_STANDBY_HOST__/'$PGPOOL_STANDBY_HOST'/g' $PGPOOL_CONFIG
sed -i 's/__PGPOOL_TRUSTED_SERVERS__/'$PGPOOL_TRUSTED_SERVERS'/g' $PGPOOL_CONFIG
sed -i 's/__PGPOOL_DELEGATE_IP__/'$PGPOOL_DELEGATE_IP'/g' $PGPOOL_CONFIG
sed -i 's/__PGPOOL_INTERFACE__/'$PGPOOL_INTERFACE'/g' $PGPOOL_CONFIG

echo "postgres:"`pg_md5 postgres` >> $PGPOOL_DIR/pcp.conf

chmod 4755 /sbin/ifconfig
chmod 4755 /usr/sbin/arping

touch /etc/pgpool-II/pool_passwd
chown postgres /etc/pgpool-II/pool_passwd

mkdir /var/log/pgpool
chown postgres /var/log/pgpool

# Change default PostgreSQL port to 5433
sed -i "s/PGPORT=5432/PGPORT=5433/g" /etc/sysconfig/pgsql/postgresql
/etc/init.d/postgresql restart

chkconfig pgpool on

# Add check status of nodes every minute into cron
if ! grep -Fq "pg_auto_attach_node" /etc/crontab; then
    echo '* * * * * root /usr/local/bin/pg_auto_attach_node' >> /etc/crontab
fi
/etc/init.d/crond restart
